@@ -99,10 +99,13 @@ class Renderer(JsRenderer, JsCacheRenderer):
             actions={a.action_name: self.action2json(a) for a in actions},
             # actors={a.actor_id: a for a in self.actors_list},
             menu=settings.SITE.get_site_menu(get_user_profile()),
-            suggestors=list(plugins.memo.parser.suggesters.keys()),  # [#,@] keytriggers
             use_dashboard_layouts=plugins.system.use_dashboard_layouts,
             site_title=settings.SITE.title,
             )
+        if settings.SITE.is_installed('memo'):
+            # [#,@] key triggers
+            data.update(
+                suggestors=list(plugins.memo.parser.suggesters.keys()))
 
         # if settings.SITE.never_build_site_cache:
         #     data.update(revision_number=settings.SITE.kernel.lino_version)
