@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Views for `lino_react.react`.
@@ -163,11 +163,16 @@ class ApiList(View):
                 html_text = ""
                 rows = []
                 for obj in ar.sliced_data_iterator:
-                    url = ar.renderer.obj2url(ar, obj)
-                    if url is not None:
-                        url = html.escape(url)
-                    html_text += """<a href="{}"><p>{}</p></a>""".format(
-                        url, ar.row_as_paragraph(obj))
+                    par = ar.row_as_paragraph(obj)  # 20230207
+                    par = ar.add_detail_link(obj, par)
+                    # par = ar.obj2str(obj, par)
+                    par = "<p>{}</p>".format(par)
+                    # url = ar.renderer.obj2url(ar, obj)
+                    # if url is not None:
+                    #     url = html.escape(url)
+                    #     # par += ' <a href="{}">(Detail)</a>'.format(url)
+                    #     par = '<a href="{}">{}</a>'.format(url, par)
+                    html_text += par
                     rows.append({'id': obj.pk})
             else:
                 html_text = None
